@@ -1,4 +1,4 @@
-from typing import Union, Sequence, Literal, Optional, Dict
+from typing import Union, Sequence, Optional, Dict
 import numpy as np
 
 def binarize_inplace(X):
