@@ -1,4 +1,4 @@
-from ._basic import import_data, make_tile_matrix, filter_cells, select_features, make_gene_matrix
+from ._basic import import_data, make_tile_matrix, make_peak_matrix, filter_cells, select_features, make_gene_matrix
 from ._knn import knn
 from ._mnn_correct import mnc_correct
 from ._scrublet import scrublet, call_doublets
